Translate Toolkit 3.11.0
************************

*Released on 8 November 2023*

This release contains improvements and bug fixes.

Changes
=======

Formats and Converters
----------------------

- Android 

  - Improved output escaping
  - Removing unit now removes attached comments as well

- JSON

  - Fix round trip of null values

- TS2

  - Expand relative locations

Tools
-----

- junitmsgfmt fixed for non-English locales

Other changes
-------------

- Added support for Python 3.12
- Consolidated CI pipeline
- Use ruff for linting and code formatting
- Move tests and test data to sit outside the modules

Contributors
============

This release was made possible by the following people:

Michal Čihař, Stuart Prescott
